@@ -1,4 +1,6 @@
 # pylint: disable=duplicate-code
+import os
+import sshtunnel
 import typing
 from contextlib import contextmanager
 
@@ -7,7 +9,7 @@ from sqlalchemy import event
 from sqlalchemy.orm import Session
 
 from ..aact_database import engine as engine_aact
-from ..database import engine
+from ..database import engine, get_engine_for_port
 
 # Uncomment the logging statements to see the SQL
 # queries that are made
@@ -37,18 +39,45 @@ def session_scope(db: typing.Optional[str] = None):
     """Provide a transactional scope around a
     series of operations."""
     # https://docs.sqlalchemy.org/en/13/orm/session_transaction.html
-    bind_engine = engine
-    if db == "aact":
-        bind_engine = engine_aact
-    session = Session(bind=bind_engine)
-    try:
-        yield session
-        session.commit()
-    except Exception:
-        session.rollback()
-        raise
-    finally:
-        session.close()
+    if os.getenv("SSH_TUNNEL"):
+        ssh_server = os.getenv("SSH_HOST")
+        ssh_username = os.getenv("SSH_USERNAME")
+        ssh_pkey_path = os.getenv("SSH_PKEY_PATH")
+        remote_bind_address = os.getenv("MYSQL_HOST")
+        with sshtunnel.SSHTunnelForwarder(
+                (ssh_server, 22),
+                ssh_username=ssh_username,
+                ssh_pkey=ssh_pkey_path,
+                remote_bind_address=(remote_bind_address, 3306),
+        ) as tunnel:
+            tunnel.start()
+            bind_engine = get_engine_for_port(tunnel.local_bind_port)
+            if db == "aact":
+                bind_engine = engine_aact
+            session = Session(bind=bind_engine)
+
+            try:
+                yield session
+                session.commit()
+            except Exception:
+                session.rollback()
+                raise
+            finally:
+                session.close()
+    else:
+        bind_engine = engine
+        if db == "aact":
+            bind_engine = engine_aact
+        session = Session(bind=bind_engine)
+
+        try:
+            yield session
+            session.commit()
+        except Exception:
+            session.rollback()
+            raise
+        finally:
+            session.close()
 
 
 def create(session, model, schema, obj):
