@@ -14,6 +14,7 @@ class CompanyOUSModel(Base):
     __tablename__ = 'companies_ous'
 
     id = Column(Integer, primary_key=True)
+    cik = Column(Integer, index=True, nullable=True)
     name = Column(String(190), unique=True, nullable=False)
     ticker = Column(String(20), nullable=True, index=True)
     exchange = Column(String(100), nullable=True)
@@ -21,6 +22,7 @@ class CompanyOUSModel(Base):
     pipeline_url = Column(String(255), nullable=True)
     ir_url = Column(String(255), nullable=True)
     is_activated = Column(Boolean, nullable=True)
+    last_crawl_date = Column(DateTime, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
