@@ -9,6 +9,7 @@ class CompanyOUSResourceSchema(Schema):
     not_blank = validate.Length(min=1, error='Field cannot be blank')
 
     id = fields.Integer(dump_only=True)
+    cik = fields.Integer()
     name = fields.String(required=True, validate=not_blank)
     ticker = fields.String(allow_none=True)
     exchange = fields.String(allow_none=True)
@@ -16,6 +17,7 @@ class CompanyOUSResourceSchema(Schema):
     pipeline_url = fields.String(allow_none=True)
     ir_url = fields.String(allow_none=True)
     is_activated = fields.Boolean(allow_none=True)
+    last_crawl_date = fields.DateTime(allow_none=True)
     updated_at = fields.DateTime(dump_only=True)
 
 
@@ -29,7 +31,9 @@ class CompanyOUSQueryParamsSchema(Schema):
 
 class CompanyOUSUpdateSchema(Schema):
     id = fields.Integer()
+    cik = fields.Integer()
     company_url = fields.String(allow_none=True)
     pipeline_url = fields.String(allow_none=True)
     ir_url = fields.String(allow_none=True)
+    last_crawl_date = fields.DateTime(allow_none=True)
     updated_at = fields.DateTime(dump_only=True)
