@@ -14,9 +14,11 @@ class DealResourceSchema(Schema):
     id = fields.Integer(dump_only=True)
     announcement_date = fields.DateTime(required=True)
     deal_value = fields.Decimal()
+    round = fields.String(allow_none=True)
     currency = fields.String(allow_none=True)
     company_sec_id = fields.Integer(allow_none=True)
     company_ous_id = fields.Integer(allow_none=True)
+    news_id = fields.Integer(allow_none=True)
     updated_at = fields.DateTime()
 
     @pre_load
