@@ -10,7 +10,6 @@ class InterventionNCTResourceSchema(Schema):
 
     id = fields.Integer(dump_only=True)
     intervention_id = fields.Integer(required=True)
-    nct_id = fields.String(required=True)
+    nct_study_id = fields.Integer(required=True)
     match_score = fields.Float(required=True)
     updated_at = fields.DateTime()
-
