@@ -16,6 +16,12 @@ class NCTStudyModel(Base):
     id = Column(Integer, primary_key=True)
     nct_id = Column(String(128), nullable=False, unique=True)
     brief_title = Column(Text)
+    enrollment = Column(Integer, nullable=True)
+    enrollment_type = Column(String(50), nullable=True)
+    brief_summary = Column(Text, nullable=True)
+    why_stopped = Column(Text, nullable=True)
+    primary_completion_date = Column(DateTime, nullable=True)
+    primary_completion_date_type = Column(String(128), nullable=True)
     study_status = Column(String(128))
     study_type = Column(String(50))
     study_start_date = Column(DateTime)
